Method: Kernel#println

Defined in:
lib/waitress/kernel.rb

#println(obj) ⇒ Object

Write a string to the output buffer, followed by a newline. Similar to echo(), this will write to the output buffer, but also adds a “\n”. This does to the client output as ‘puts()’ does to STDOUT. Use this to write data to the output stream



183
184
185
# File 'lib/waitress/kernel.rb', line 183

def println obj
  echo(obj.to_s + "\n")
end